@@ -50,7 +50,14 @@ class Pipeline(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Pipeline.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["PipelineProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -97,7 +104,17 @@ class PipelineProps:
         :param state: Property state: The new state of the MPS queue. Active: The MPS queue is active. Jobs in the MPS queue can be scheduled and run by MPS. Paused: The MPS queue is paused. Jobs in the MPS queue cannot be scheduled or run by MPS, and all jobs remain in the Submitted state. Jobs that are running will not be affected.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(PipelineProps.__init__)
+            def stub(
+                *,
+                name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                notify_config: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Union["RosPipeline.NotifyConfigProperty", typing.Dict[str, typing.Any]]]] = None,
+                role: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                speed: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                speed_level: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
+                state: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument notify_config", value=notify_config, expected_type=type_hints["notify_config"])
             check_type(argname="argument role", value=role, expected_type=type_hints["role"])
@@ -223,7 +240,14 @@ class RosPipeline(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosPipeline.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["RosPipelineProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -239,7 +263,9 @@ class RosPipeline(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosPipeline._render_properties)
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -270,7 +296,9 @@ class RosPipeline(
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosPipeline, "enable_resource_property_constraint").fset)
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
@@ -289,7 +317,11 @@ class RosPipeline(
     @name.setter
     def name(self, value: typing.Union[builtins.str, ros_cdk_core.IResolvable]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosPipeline, "name").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -312,7 +344,11 @@ class RosPipeline(
         value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosPipeline.NotifyConfigProperty"]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosPipeline, "notify_config").fset)
+            def stub(
+                value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosPipeline.NotifyConfigProperty"]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "notifyConfig", value)
 
@@ -332,7 +368,11 @@ class RosPipeline(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosPipeline, "role").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "role", value)
 
@@ -360,7 +400,11 @@ class RosPipeline(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosPipeline, "speed").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "speed", value)
 
@@ -380,7 +424,11 @@ class RosPipeline(
         value: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosPipeline, "speed_level").fset)
+            def stub(
+                value: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "speedLevel", value)
 
@@ -404,7 +452,11 @@ class RosPipeline(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosPipeline, "state").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "state", value)
 
@@ -425,7 +477,13 @@ class RosPipeline(
             :param topic: 
             '''
             if __debug__:
-                type_hints = typing.get_type_hints(RosPipeline.NotifyConfigProperty.__init__)
+                def stub(
+                    *,
+                    queue_name: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                    topic: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                ) -> None:
+                    ...
+                type_hints = typing.get_type_hints(stub)
                 check_type(argname="argument queue_name", value=queue_name, expected_type=type_hints["queue_name"])
                 check_type(argname="argument topic", value=topic, expected_type=type_hints["topic"])
             self._values: typing.Dict[str, typing.Any] = {}
@@ -499,7 +557,17 @@ class RosPipelineProps:
         :param state: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosPipelineProps.__init__)
+            def stub(
+                *,
+                name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                notify_config: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Union[RosPipeline.NotifyConfigProperty, typing.Dict[str, typing.Any]]]] = None,
+                role: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                speed: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                speed_level: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
+                state: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument notify_config", value=notify_config, expected_type=type_hints["notify_config"])
             check_type(argname="argument role", value=role, expected_type=type_hints["role"])
